\name{coco4r}
\alias{coco4r}
\alias{coco4r.coconad}
\alias{coco4r.genpsp}
\alias{coco4r.estpsp}
\alias{coco4r.psp2bdr}
\alias{coco4r.patred}
\alias{coconad}
\alias{genpsp}
\alias{estpsp}
\alias{psp2bdr}
\alias{patred}

\title{CoCoNAD}
\description{\strong{Co}ntinuous-time \strong{C}l\strong{o}sed
             \strong{N}euron \strong{A}ssembly \strong{D}etection}

\usage{
coco4r.coconad(trains, target="c", width=0.003, supp=2,
               zmin=2, zmax=-1, report="a", algo="r", mode="",
               border=NULL)
coco4r.genpsp (trains, target="c", width=0.003, supp=2,
               zmin=2, zmax=-1, report="|", algo="r", mode="",
               cnt=1000, beg=-Inf, end=+Inf,
               surr="p", rand="u", sigma=0.005, delta=0.03,
               seed=0, cpus=0)
coco4r.estpsp (trains, target="s", width=0.003, supp=2,
               zmin=2, zmax=-1, report="|", equiv=10000,
               alpha=0.5, smpls=1000, seed=0)
coco4r.psp2bdr(psp)
coco4r.patred (pats, method="S", border=NULL, addis=TRUE)
}

\arguments{
\item{trains}{ a list of numeric vectors with the event times;
               each vector refers to one event type.}
\item{target}{ a string specifying the target type; see
               \code{coco4r.targets} for the available options.}
\item{width}{  analysis window width.}
\item{supp}{   minimum support (number of occurrences).}
\item{zmin}{   minimum pattern size (number of items).}
\item{zmax}{   maximum pattern size (number of items);
               \code{NA} or negative means no limit.}
\item{report}{ a string indicating the return type;
               "a": frequent patterns, "#": pattern spectrum in
               column format, "=": pattern spectrum in row format.}
\item{algo}{   a string indicating which CoCoNAD algorithm variant
               to use; see \code{coco4r.algos} for the available
               options.}
\item{mode}{   a string the characters of which indicate operation
               mode options;
               'x': do not use perfect extension pruning;
               'p': do not reorder conditional train databases}
\item{border}{ a numeric array with minimum support values per
               pattern size; index 1 refers to size 0, index 2
               to size 1 etc.}
\item{cnt}{    number of surrogate data sets to generate.}
\item{beg}{    beginning of the range of points; to limit the location
               of dithered and displaced points in surrogate data sets;
               if not given, determined as largest integer no larger
               than the smallest point.}
\item{end}{    end of the range of points; to limit the location
               of dithered and displaced points in surrogate data sets;
               if not given, determined as smallest integer no smaller
               than the largest point.}
\item{surr}{   surrogate data generation method;
               see \code{coco4r.surrs} for the available options.}
\item{rand}{   random function density identifier;
               see \code{coco4r.rands} for the available options.}
\item{sigma}{  random dispersion parameter; standard deviation or
               half the base width of the density.}
\item{delta}{  block size for block permutations}
\item{seed}{   seed for random number generator; if 0, the current
               time will be used.}
\item{cpus}{   number of CPUs to use; if 0 or negative, all CPUs
               reported as available by the system will be used.}
\item{psp}{    a pattern spectrum as a list of three numeric vectors
               of equal length; the first states the pattern sizes,
               the second the support values, and the third the
               occurrence frequencies of patterns with the
               corresponding (size,support) signature; the third
               column may be missing in an argument passed to
               \code{coco4r.psp2bdr}.}
\item{equiv}{  equivalent number of surrogate data sets.}
\item{alpha}{  probability dispersion factor.}
\item{smpls}{  number of samples per item set size.}
\item{pats}{   a set of patterns, as produced by the function
               \code{coco4r.coconad}.}
\item{method}{ pattern set reduction method;
               see \code{coco4r.reds} for the available options.}
\item{addis}{  a logical indicating whether pairwise intersections
               should be added to the pattern set.}
}

\value{
\code{coco4r.coconad} returns
a pattern set as a list of pairs (lists with two elements).
The first element of each pair is an array of integers, which are
the items of a frequent item set, where the items are the indices
of the trains in the input. The second element of each pair is the
support value of the item set in the first element.

\code{coco4r.genpsp} and \code{coco4r.estpsp} return
a pattern spectrum, either as a list with three columns
(for \code{report = "#"}, default) or as a list of numeric
vectors with three elements (for \code{report = "="}).
The first column/element is the pattern size (number of items),
the second column/element is the pattern support (number of occurrences)
the third column/element is the number of patterns with the signature
(size,support) given by the first two columns/elements.

\code{coco4r.psp2bdr} returns
a pattern border as a numeric array with named elements. The names
are the pattern sizes, the elements the corresponding minimum support
values a pattern of that size has to reach in order to be considered
significant. This list can be passed to the function
\code{coco4r.coconad} for the argument \code{border}.

\code{coco4r.patred} returns
a reduced pattern set in the same form as \code{coco4r.coconad}.
}

\author{Christian Borgelt \email{christian@borgelt.net}}

\examples{
library(coco4r)                 # load the coconad for R library
data(trains)                    # load the example spike trains
trains <- tapply(trains[,2], factor(trains[,1]), c)
                                # reshape into required input format
# psp    <- coco4r.genpsp(trains) # generate a pattern spectrum
psp    <- coco4r.estpsp(trains) # estimate a pattern spectrum
border <- coco4r.psp2bdr(psp)   # extract the decision border
pats   <- coco4r.coconad(trains, border=border)
                                # find significant frequent patterns
pats   <- coco4r.patred(pats, "S", border)
                                # reduce the pattern set
}

\keyword{spike train}
\keyword{point process}
\keyword{event sequence}
\keyword{frequent pattern mining}

